@@ -22,8 +22,8 @@
       steps and inspections
 
   Step:
-      represents one step of the software supply chain, performed by one or many
-      functionaries, who are identified by a key also stored to the layout
+      represents one step of the software supply chain, performed by one or
+      many functionaries, who are identified by a key also stored to the layout
 
   Inspection:
       represents a hook that is run at verification
@@ -41,12 +41,12 @@ from dateutil.parser import parse
 from in_toto.models.common import Signable, ValidationMixin
 import in_toto.rulelib
 import in_toto.exceptions
-import in_toto.formats
 
 import securesystemslib.exceptions
 import securesystemslib.formats
 import securesystemslib.schema
 import securesystemslib.interface
+import securesystemslib.gpg.functions
 
 
 # Link metadata for sublayouts are expected to be found in a subdirectory
@@ -378,18 +378,18 @@ class Layout(Signable):
     <Arguments>
       key:
               A functionary public key conformant with
-              in_toto.formats.ANY_PUBKEY_SCHEMA.
+              securesystemslib.formats.ANY_PUBKEY_SCHEMA.
 
     <Exceptions>
       securesystemslib.exceptions.FormatError
               If the passed key does not match
-              in_toto.formats.ANY_PUBKEY_SCHEMA.
+              securesystemslib.formats.ANY_PUBKEY_SCHEMA.
 
     <Returns>
       The added functionary public key.
 
     """
-    in_toto.formats.ANY_PUBKEY_SCHEMA.check_match(key)
+    securesystemslib.formats.ANY_PUBKEY_SCHEMA.check_match(key)
     keyid = key["keyid"]
     self.keys[keyid] = key
     return key
@@ -449,7 +449,7 @@ class Layout(Signable):
               securesystemslib.formats.PATH_SCHEMA.
 
               If the key loaded from the GPG keychain does not match
-              in_toto.formats.ANY_PUBKEY_SCHEMA.
+              securesystemslib.formats.ANY_PUBKEY_SCHEMA.
 
     <Returns>
       The added functionary public key.
@@ -459,7 +459,7 @@ class Layout(Signable):
     if gpg_home: # pragma: no branch
       securesystemslib.formats.PATH_SCHEMA.check_match(gpg_home)
 
-    key = in_toto.gpg.functions.gpg_export_pubkey(gpg_keyid,
+    key = securesystemslib.gpg.functions.export_pubkey(gpg_keyid,
         homedir=gpg_home)
     return self.add_functionary_key(key)
 
@@ -523,7 +523,7 @@ class Layout(Signable):
               securesystemslib.formats.PATH_SCHEMA.
 
               If any of the keys loaded from the GPG keychain does not
-              match in_toto.formats.ANY_PUBKEY_SCHEMA.
+              match securesystemslib.formats.ANY_PUBKEY_SCHEMA.
 
     <Returns>
       A dictionary of the added functionary public keys with the key's keyids
@@ -570,14 +570,14 @@ class Layout(Signable):
 
   def _validate_keys(self):
     """Private method to ensure that the keys contained are right."""
-    in_toto.formats.ANY_PUBKEY_DICT_SCHEMA.check_match(self.keys)
+    securesystemslib.formats.ANY_PUBKEY_DICT_SCHEMA.check_match(self.keys)
 
 
   def _validate_steps_and_inspections(self):
     """Private method to verify that the list of steps and inspections are
     correctly formed."""
     names_seen = set()
-    if type(self.steps) != list:
+    if not isinstance(self.steps, list):
       raise securesystemslib.exceptions.FormatError(
           "The steps field should be a list!")
 
@@ -594,7 +594,7 @@ class Layout(Signable):
             " unique within a layout.".format(step.name))
       names_seen.add(step.name)
 
-    if type(self.inspect) != list:
+    if not isinstance(self.inspect, list):
       raise securesystemslib.exceptions.FormatError(
           "The inspect field should a be a list!")
 
@@ -707,7 +707,7 @@ class SupplyChainItem(ValidationMixin):
 
   def _validate_expected_materials(self):
     """Private method to check that material rules are correctly formed."""
-    if type(self.expected_materials) != list:
+    if not isinstance(self.expected_materials, list):
       raise securesystemslib.exceptions.FormatError(
           "Material rules should be a list!")
 
@@ -717,7 +717,7 @@ class SupplyChainItem(ValidationMixin):
 
   def _validate_expected_products(self):
     """Private method to check that product rules are correctly formed."""
-    if type(self.expected_products) != list:
+    if not isinstance(self.expected_products, list):
       raise securesystemslib.exceptions.FormatError(
           "Product rules should be a list!")
 
@@ -829,7 +829,7 @@ class Step(SupplyChainItem):
 
   def _validate_threshold(self):
     """Private method to check that the threshold field is set to an int."""
-    if type(self.threshold) != int:
+    if not isinstance(self.threshold, int):
       raise securesystemslib.exceptions.FormatError(
           "Invalid threshold '{}', value must be an int."
           .format(self.threshold))
@@ -837,7 +837,7 @@ class Step(SupplyChainItem):
 
   def _validate_pubkeys(self):
     """Private method to check that the pubkeys is a list of keyids."""
-    if type(self.pubkeys) != list:
+    if not isinstance(self.pubkeys, list):
       raise securesystemslib.exceptions.FormatError(
           "The pubkeys field should be a list!")
 
@@ -847,7 +847,7 @@ class Step(SupplyChainItem):
 
   def _validate_expected_command(self):
     """Private method to check that the expected_command is proper."""
-    if type(self.expected_command) != list:
+    if not isinstance(self.expected_command, list):
       raise securesystemslib.exceptions.FormatError(
           "The expected command field is malformed!")
 
@@ -944,6 +944,6 @@ class Inspection(SupplyChainItem):
 
   def _validate_run(self):
     """Private method to check that the expected command is correct."""
-    if type(self.run) != list:
+    if not isinstance(self.run, list):
       raise securesystemslib.exceptions.FormatError(
           "The run field is malformed!")
