@@ -25,9 +25,7 @@ import json
 import securesystemslib.keys
 import securesystemslib.formats
 import securesystemslib.exceptions
-
-import in_toto.formats
-import in_toto.gpg.functions
+import securesystemslib.gpg.functions
 
 from in_toto.models.common import ValidationMixin
 from in_toto.models.link import Link
@@ -168,7 +166,7 @@ class Metablock(ValidationMixin):
     """
     <Purpose>
       Signs the utf-8 encoded canonical JSON bytes of the Link or Layout object
-      contained in `self.signed` using `gpg.functions.gpg_sign_object` and
+      contained in `self.signed` using `gpg.functions.create_signature` and
       appends the created signature to `self.signatures`.
 
     <Arguments>
@@ -180,7 +178,7 @@ class Metablock(ValidationMixin):
               is used
 
     <Exceptions>
-      in_toto.gpg.exceptions.CommandError:
+      securesystemslib.gpg.exceptions.CommandError:
               If the gpg signing command returned a non-zero exit code, e.g.
               because the key has expired.
 
@@ -189,7 +187,7 @@ class Metablock(ValidationMixin):
       The dictionary representation of the newly created signature.
 
     """
-    signature = in_toto.gpg.functions.gpg_sign_object(
+    signature = securesystemslib.gpg.functions.create_signature(
         self.signed.signable_bytes, gpg_keyid, gpg_home)
 
     self.signatures.append(signature)
@@ -206,10 +204,10 @@ class Metablock(ValidationMixin):
       encoded canonical JSON bytes of the Link or Layout object, contained in
       `self.signed`.
 
-      If the signature matches `in_toto.gpg.formats.SIGNATURE_SCHEMA`,
-      `in_toto.gpg.functions.gpg_verify_signature` is used for verification,
+      If the signature matches securesystemslib.formats.GPG_SIGNATURE_SCHEMA,
+      `securesystemslib.gpg.functions.verify_signature` is used,
       if the signature matches `securesystemslib.formats.SIGNATURE_SCHEMA`
-      `securesystemslib.keys.verify_signature` is used.
+      `securesystemslib.keys.verify_signature`.
 
       Note: In case of securesystemslib we actually pass the dictionary
       representation of the data to be verified and
@@ -219,12 +217,12 @@ class Metablock(ValidationMixin):
     <Arguments>
       verification_key:
               Verifying key in the format:
-              in_toto.formats.ANY_VERIFICATION_KEY_SCHEMA
+              securesystemslib.formats.ANY_VERIFICATION_KEY_SCHEMA
 
     <Exceptions>
       FormatError
             If the passed key is not conformant with
-            `in_toto.formats.ANY_VERIFICATION_KEY_SCHEMA`
+            securesystemslib.formats.ANY_VERIFICATION_KEY_SCHEMA
 
       SignatureVerificationError
             If the Metablock does not carry a signature signed with the
@@ -233,18 +231,19 @@ class Metablock(ValidationMixin):
 
             If the signature corresponding to the passed verification key or
             one of its subkeys does not match securesystemslib's or
-            in_toto.gpg's signature schema.
+            securesystemslib.gpg's signature schema.
 
             If the signature to be verified is malformed or invalid.
 
-      in_toto.gpg.exceptions.KeyExpirationError:
+      securesystemslib.gpg.exceptions.KeyExpirationError:
             if the passed verification key is an expired gpg key
 
     <Returns>
       None.
 
     """
-    in_toto.formats.ANY_VERIFICATION_KEY_SCHEMA.check_match(verification_key)
+    securesystemslib.formats.ANY_VERIFICATION_KEY_SCHEMA.check_match(
+        verification_key)
     verification_keyid = verification_key["keyid"]
 
     # Find a signature that corresponds to the keyid of the passed
@@ -262,8 +261,8 @@ class Metablock(ValidationMixin):
       raise SignatureVerificationError("No signature found for key '{}'"
           .format(verification_keyid))
 
-    if in_toto.gpg.formats.SIGNATURE_SCHEMA.matches(signature):
-      valid = in_toto.gpg.functions.gpg_verify_signature(signature,
+    if securesystemslib.formats.GPG_SIGNATURE_SCHEMA.matches(signature):
+      valid = securesystemslib.gpg.functions.verify_signature(signature,
           verification_key, self.signed.signable_bytes)
 
     elif securesystemslib.formats.SIGNATURE_SCHEMA.matches(signature):
@@ -292,11 +291,12 @@ class Metablock(ValidationMixin):
 
   def _validate_signatures(self):
     """Private method to check that the 'signatures' attribute is a list of
-    signatures in the format 'in_toto.formats.ANY_SIGNATURE_SCHEMA'. """
+    signatures in the format 'securesystemslib.formats.ANY_SIGNATURE_SCHEMA'.
+    """
 
     if not isinstance(self.signatures, list):
       raise securesystemslib.exceptions.FormatError("The Metablock's"
         " 'signatures' property has to be of type 'list'.")
 
     for signature in self.signatures:
-      in_toto.formats.ANY_SIGNATURE_SCHEMA.check_match(signature)
+      securesystemslib.formats.ANY_SIGNATURE_SCHEMA.check_match(signature)
