@@ -44,7 +44,7 @@ from in_toto.models.layout import SUBLAYOUT_LINK_DIR_FORMAT
 from in_toto.exceptions import (RuleVerificationError, LayoutExpiredError,
     ThresholdVerificationError, BadReturnValueError,
     SignatureVerificationError)
-from in_toto.gpg.exceptions import KeyExpirationError
+from securesystemslib.gpg.exceptions import KeyExpirationError
 import in_toto.rulelib
 
 # Inherits from in_toto base logger (c.f. in_toto.log)
@@ -347,21 +347,21 @@ def verify_layout_signatures(layout_metablock, keys_dict):
 
     keys_dict:
             A dictionary of keys to verify the signatures conformant with
-            securesystemslib.formats.ANY_VERIFICATION_KEY_DICT_SCHEMA.
+            securesystemslib.formats.VERIFICATION_KEY_DICT_SCHEMA.
 
   <Exceptions>
     securesystemslib.exceptions.FormatError
-      if the passed key dict does not match ANY_VERIFICATION_KEY_DICT_SCHEMA.
+      if the passed key dict does not match VERIFICATION_KEY_DICT_SCHEMA.
 
     SignatureVerificationError
       if an empty verification key dictionary was passed, or
       if any of the passed verification keys fails to verify a signature.
 
-    in_toto.gpg.exceptions.KeyExpirationError:
+    securesystemslib.gpg.exceptions.KeyExpirationError:
       if any of the passed verification keys is an expired gpg key
 
   """
-  in_toto.formats.ANY_VERIFICATION_KEY_DICT_SCHEMA.check_match(keys_dict)
+  securesystemslib.formats.VERIFICATION_KEY_DICT_SCHEMA.check_match(keys_dict)
 
   # Fail if an empty verification key dictionary was passed
   if len(keys_dict) < 1:
